[Libreoffice-commits] core.git: qadevOOo/runner

Noel Grandin noel at peralex.com
Fri Oct 16 01:52:57 PDT 2015


 qadevOOo/runner/lib/MultiMethodTest.java |    2 +-
 qadevOOo/runner/lib/RunState.java        |    4 ++--
 qadevOOo/runner/lib/SimpleStatus.java    |    4 ++--
 qadevOOo/runner/lib/Status.java          |    8 ++++----
 4 files changed, 9 insertions(+), 9 deletions(-)

New commits:
commit c429df73d5d7f6091b830c4ad2a9bdafdfb96ad7
Author: Noel Grandin <noel at peralex.com>
Date:   Fri Oct 16 09:19:51 2015 +0200

    rename test state 'PASSED' to 'COMPLETED'
    
    which is more accurate since 'PASSED' normally means 'successful',
    which is not the case here
    
    Change-Id: I8e9368a810e7be823655f69646fd15feb9f8f502

diff --git a/qadevOOo/runner/lib/MultiMethodTest.java b/qadevOOo/runner/lib/MultiMethodTest.java
index c93f3ad..fd27c42 100644
--- a/qadevOOo/runner/lib/MultiMethodTest.java
+++ b/qadevOOo/runner/lib/MultiMethodTest.java
@@ -339,7 +339,7 @@ public class MultiMethodTest
         executeMethod(method);
         Status mtStatus = tRes.getStatusFor(method);
 
-        if (mtStatus != null && (!mtStatus.isPassed() || mtStatus.isFailed()))
+        if (mtStatus != null && (!mtStatus.isCompleted() || mtStatus.isFailed()))
         {
             log.println("! Required method " + method + " failed");
             throw new StatusException(mtStatus);
diff --git a/qadevOOo/runner/lib/SimpleStatus.java b/qadevOOo/runner/lib/SimpleStatus.java
index e65666d..b404dcb 100644
--- a/qadevOOo/runner/lib/SimpleStatus.java
+++ b/qadevOOo/runner/lib/SimpleStatus.java
@@ -47,8 +47,8 @@ class SimpleStatus {
     protected SimpleStatus( RunState runState, boolean bSuccessful ) {
         this.bSuccessful = bSuccessful;
         this.runState = runState;
-        if ( runState == RunState.PASSED ) {
-            runStateString = "PASSED";
+        if ( runState == RunState.COMPLETED ) {
+            runStateString = "COMPLETED";
         } else if ( runState == RunState.SKIPPED ) {
             runStateString = "SKIPPED";
         } else if ( runState == RunState.EXCEPTION ) {
diff --git a/qadevOOo/runner/lib/RunState.java b/qadevOOo/runner/lib/RunState.java
index eeee2d8..4b1eaa5 100644
--- a/qadevOOo/runner/lib/RunState.java
+++ b/qadevOOo/runner/lib/RunState.java
@@ -21,9 +21,9 @@ package lib;
 public enum RunState {
 
     /**
      * The constant represents PASSED runtime state.
      */
-    PASSED,
+    COMPLETED,
 
     /**
      * The constant represents EXCEPTION runtime state.
@@ -21,9 +21,9 @@ package lib;
 
     /**
-     * The constant represents PASSED runtime state.
+     * The constant represents COMPLETED runtime state.
      */
diff --git a/qadevOOo/runner/lib/Status.java b/qadevOOo/runner/lib/Status.java
index ba28a4c..e96e4ef 100644
--- a/qadevOOo/runner/lib/Status.java
+++ b/qadevOOo/runner/lib/Status.java
@@ -62,7 +62,7 @@ public class Status extends SimpleStatus {
      * otherwise).
      */
     public static Status passed( boolean bSuccessful ) {
-        return new Status(RunState.PASSED, bSuccessful );
+        return new Status(RunState.COMPLETED, bSuccessful );
     }
 
     /**
@@ -112,10 +112,10 @@ public class Status extends SimpleStatus {
     }
 
     /**
      * Checks whether the status runstate is passed.
      */
-    public boolean isPassed() {
-        return getRunState() == RunState.PASSED;
+    public boolean isCompleted() {
+        return getRunState() == RunState.COMPLETED;
     }
 
     /**
@@ -112,10 +112,10 @@ public class Status extends SimpleStatus {
 
     /**
-     * Checks whether the status runstate is passed.
+     * Checks whether the status runstate is completed.
      */


More information about the Libreoffice-commits mailing list